@@ -1,8 +1,12 @@
 ## File Name: invariance_alignment_center_parameters.R
-## File Version: 0.03
+## File Version: 0.10
 
-invariance_alignment_center_parameters <- function(alpha0, psi0, center)
+invariance_alignment_center_parameters <- function(alpha0, psi0, center,
+    reparam=FALSE, convert=FALSE)
 {
+    if (reparam & convert){
+        alpha0 <- alpha0 * psi0
+    }
     if (center){
         alpha0 <- alpha0 - mean(alpha0)
         log_psi <- log(psi0)
