@@ -1,11 +1,12 @@
 ## File Name: lsem_fitsem.R
-## File Version: 0.554
+## File Version: 0.566
 
 lsem_fitsem <- function( dat, weights, lavfit, fit_measures, NF, G, moderator.grid,
                 verbose, pars, standardized, variables_model, sufficient_statistics,
                 lavaan_fct, lavmodel, use_lavaan_survey=TRUE, pseudo_weights=0,
                 est_joint=FALSE, par_invariant=NULL, par_linear=NULL, par_quadratic=NULL,
-                partable_joint=NULL, se="standard", ... )
+                partable_joint=NULL, se="standard", moderator_variable=NULL,
+                loc_linear_smooth=NULL, ... )
 {
 
     parameters <- NULL
@@ -27,7 +28,9 @@ lsem_fitsem <- function( dat, weights, lavfit, fit_measures, NF, G, moderator.gr
     #- sufficient statistics
     if (sufficient_statistics){
         sample_stats <- lsem_fitsem_compute_sufficient_statistics(G=G, dat=dat,
-                    variables_model=variables_model, weights=weights)
+                    variables_model=variables_model, weights=weights,
+                    moderator_variable=moderator_variable,
+                    loc_linear_smooth=loc_linear_smooth, moderator.grid=moderator.grid)
     }
     if (est_joint & (! sufficient_statistics)){
         N <- nrow(dat)
